==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Architecture/MachineLearning/AwsDeepComposer.md <==
# AwsDeepComposer


```text
aws-20210730/Architecture/MachineLearning/AwsDeepComposer
```

```text
include('aws-20210730/Architecture/MachineLearning/AwsDeepComposer')
```



| Illustration | AwsDeepComposer | AwsDeepComposerCard | AwsDeepComposerGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Architecture/MachineLearning/AwsDeepComposer.png) | ![illustration for AwsDeepComposer](../../../aws-20210730/Architecture/MachineLearning/AwsDeepComposer.Local.png) | ![illustration for AwsDeepComposerCard](../../../aws-20210730/Architecture/MachineLearning/AwsDeepComposerCard.Local.png) | ![illustration for AwsDeepComposerGroup](../../../aws-20210730/Architecture/MachineLearning/AwsDeepComposerGroup.Local.png) |




## AwsDeepComposer

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDeepComposer
include('aws-20210730/Architecture/MachineLearning/AwsDeepComposer')

' renders the element
AwsDeepComposer('AwsDeepComposer', 'Aws Deep Composer', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDeepComposer
include('aws-20210730/Architecture/MachineLearning/AwsDeepComposer')

' renders the element
AwsDeepComposer('AwsDeepComposer', 'Aws Deep Composer', 'an optional tech label')
@enduml
```

## AwsDeepComposerCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDeepComposerCard
include('aws-20210730/Architecture/MachineLearning/AwsDeepComposer')

' renders the element
AwsDeepComposerCard('AwsDeepComposerCard', 'Aws Deep Composer Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDeepComposerCard
include('aws-20210730/Architecture/MachineLearning/AwsDeepComposer')

' renders the element
AwsDeepComposerCard('AwsDeepComposerCard', 'Aws Deep Composer Card', 'an optional description')
@enduml
```

## AwsDeepComposerGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDeepComposerGroup
include('aws-20210730/Architecture/MachineLearning/AwsDeepComposer')

' renders the element
AwsDeepComposerGroup('AwsDeepComposerGroup', 'Aws Deep Composer Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDeepComposerGroup
include('aws-20210730/Architecture/MachineLearning/AwsDeepComposer')

' renders the element
AwsDeepComposerGroup('AwsDeepComposerGroup', 'Aws Deep Composer Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Architecture/MachineLearning/AwsDeepComposer.md <==
# AwsDeepComposer


```text
aws-20210730/Architecture/MachineLearning/AwsDeepComposer
```

```text
include('aws-20210730/Architecture/MachineLearning/AwsDeepComposer')
```



| Illustration | AwsDeepComposer | AwsDeepComposerCard | AwsDeepComposerGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Architecture/MachineLearning/AwsDeepComposer.png) | ![illustration for AwsDeepComposer](../../../aws-20210730/Architecture/MachineLearning/AwsDeepComposer.Local.png) | ![illustration for AwsDeepComposerCard](../../../aws-20210730/Architecture/MachineLearning/AwsDeepComposerCard.Local.png) | ![illustration for AwsDeepComposerGroup](../../../aws-20210730/Architecture/MachineLearning/AwsDeepComposerGroup.Local.png) |




## AwsDeepComposer

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDeepComposer
include('aws-20210730/Architecture/MachineLearning/AwsDeepComposer')

' renders the element
AwsDeepComposer('AwsDeepComposer', 'Aws Deep Composer', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDeepComposer
include('aws-20210730/Architecture/MachineLearning/AwsDeepComposer')

' renders the element
AwsDeepComposer('AwsDeepComposer', 'Aws Deep Composer', 'an optional tech label')
@enduml
```

## AwsDeepComposerCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDeepComposerCard
include('aws-20210730/Architecture/MachineLearning/AwsDeepComposer')

' renders the element
AwsDeepComposerCard('AwsDeepComposerCard', 'Aws Deep Composer Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDeepComposerCard
include('aws-20210730/Architecture/MachineLearning/AwsDeepComposer')

' renders the element
AwsDeepComposerCard('AwsDeepComposerCard', 'Aws Deep Composer Card', 'an optional description')
@enduml
```

## AwsDeepComposerGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDeepComposerGroup
include('aws-20210730/Architecture/MachineLearning/AwsDeepComposer')

' renders the element
AwsDeepComposerGroup('AwsDeepComposerGroup', 'Aws Deep Composer Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDeepComposerGroup
include('aws-20210730/Architecture/MachineLearning/AwsDeepComposer')

' renders the element
AwsDeepComposerGroup('AwsDeepComposerGroup', 'Aws Deep Composer Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
